%define ALD_Ver		2.0

#USE gcc-7.5.0

%define OrgName kmod
%define mC_Version 1.2.4s

Name:         mC-%{OrgName}
License:      GPL
Summary:      Basic kernel module utilities
Version:      30
Release:      %{mC_Version}.0

#https://mirrors.edge.kernel.org/pub/linux/utils/kernel/kmod/

Source: %{OrgName}-%{version}.tar.xz
#Source2: %{OrgName}-%{version}-patches.tgz

%define DestDir		/Embedded/mC/%{mC_Version}

# -----------------------------------------------------
%define auto_local %{_sourcedir}/AUTO_LOCAL-1.sh
%define have_auto_local %(if test -x %{auto_local} ; then echo 1 ; else echo 0 ; fi)

%if %{_target_cpu} == %{_build_cpu}
%define _srcrpmdir	%{_topdir}/SRPMS/%{ALD_Ver}/mC/%{mC_Version}
%define _CROSS 0
%else
# rpm --target=x86_64 -ba xxxxx.spec
%define _srcrpmdir	%{_topdir}/SRPMS/tmp
%define _CROSS 1
%endif

# -----------------------------------------------------

%if %{have_auto_local}
%define __os_install_post %{nil}
%endif

%if %{_CROSS}
%define CrossPath /cross/%{_target_cpu}
%else
%define CrossPath %{nil}
%endif

#------------------ CROSS DIR --------------------

%define _prefix /usr/mC/%{mC_Version}
%define _datadir /usr/share
%define _bindir /sbin
%define _sbindir /sbin
%define _sysconfdir /etc
%define docdir %{_defaultdocdir}/%{OrgName}

%define target %{_arch}-linux-musl

# ------------------- description ------------------------------------
%description
Basic kernel module utilities

# ------------------- setup ------------------------------------------
%Prep
%setup -q -n %{OrgName}-%{version}

sed -i s:"	\$(AM_V_CCLD)\$(libkmod_libkmod_la_LINK)":"#	\$(AM_V_CCLD)\$(libkmod_libkmod_la_LINK)": Makefile.in

#tar -xaf %SOURCE2
#patch -b -z .orig -p0<patches/static.patch
#patch -b -z .orig -p0<patches/bultin_errmsg.patch

# ------------------- Build ------------------------------------------
%Build
export PATH=$PATH:%{CrossPath}%{_prefix}/bin
export GCC_NoHostPath=d

%if %{_arch} == "i386"
OPTFLAGS="-Os -march=i586 -mpreferred-stack-boundary=2 -falign-functions=1 -falign-jumps=1 -falign-loops=1 -fomit-frame-pointer"
%endif
%if %{_arch} == "x86_64"
OPTFLAGS="-Os -fno-tree-loop-optimize -fno-tree-dominator-opts -fno-strength-reduce"
%endif
%if %{_arch} == "arm"
OPTFLAGS="%{optflags} -Os -munaligned-access"
%endif

OPTFLAGS="$OPTFLAGS -fno-asynchronous-unwind-tables -ffunction-sections -fdata-sections"
export CFLAGS="$OPTFLAGS -std=gnu99"
export LDFLAGS="-Wl,--gc-sections"
export CC="%{target}-gcc"

./configure \
	--prefix=%{_prefix} \
	--exec-prefix=%{_exec_prefix} \
	--bindir=%{_bindir} \
	--sbindir=%{_sbindir} \
	--sysconfdir=%{_sysconfdir} \
	--datadir=%{_datadir} \
	--includedir=%{_includedir} \
	--libdir=%{_libdir} \
	--libexecdir=%{_libexecdir} \
	--localstatedir=%{_localstatedir} \
	--sharedstatedir=%{_sharedstatedir} \
	--mandir=%{_mandir} \
	--infodir=%{_infodir} \
	--includedir=%{_includedir} \
	--disable-libtool-lock \
	--disable-experimental \
	--disable-test-modules \
	--disable-gtk-doc \
	--with-zlib \
	--with-xz \
	&>FConfigure_log.txt

make V=1 &>FMake_log.txt

# ------------------- Install ----------------------------------------
%Install
export PATH=$PATH:%{CrossPath}%{_prefix}/bin
export GCC_NoHostPath=d

rm -rf $RPM_BUILD_ROOT
mkdir -p %{_srcrpmdir}
mkdir -p $RPM_BUILD_ROOT%{docdir}

make DESTDIR=$RPM_BUILD_ROOT install &>FInstall_log.txt
cp -a README.md $RPM_BUILD_ROOT%{docdir}/
ln -s /usr/share/doc/lgpl-2.1.txt $RPM_BUILD_ROOT%{docdir}/COPYING

rm -r $RPM_BUILD_ROOT/%{_datadir}/bash-completion
rm -r $RPM_BUILD_ROOT/usr/mC

pushd $RPM_BUILD_ROOT/%{_sbindir}
  ln -s kmod depmod
  ln -s kmod insmod
  ln -s kmod lsmod
  ln -s kmod modinfo
  ln -s kmod modprobe
  ln -s kmod rmmod
popd

%if %{have_auto_local}
  %{auto_local} -build_cpu=%{_build_cpu} -target_cpu=%{_target_cpu} \
	-target_platform=%{target}-
%endif  # have_auto_local

# ------------------- Clean ------------------------------------------
%Clean
%if %{have_auto_local}
  %{auto_local} -build_cpu=%{_build_cpu} -target_cpu=%{_target_cpu} \
	-ALD_Ver=%{ALD_Ver} -RpmMovePath=%{DestDir} -tar_arg=bzip2
%endif  # have_auto_local

# ------------------- Files ------------------------------------------
%files
%{_sbindir}
%{_mandir}
%{docdir}
